@@ -25,9 +25,11 @@
 
 #include "config.h"
 
+#include <gio/gio.h>
 #include <glib.h>
 #include <tracker-sparql.h>
 
+#include "photos-filterable.h"
 #include "photos-item-manager.h"
 #include "photos-local-item.h"
 #include "photos-query.h"
@@ -40,16 +42,59 @@
 
 struct _PhotosItemManagerPrivate
 {
+  GCancellable *loader_cancellable;
+  GHashTable *collections;
   GIOExtensionPoint *extension_point;
   GQueue *collection_path;
-  PhotosBaseManager *col_mngr;
+  PhotosBaseItem *active_collection;
   PhotosTrackerChangeMonitor *monitor;
 };
 
+enum
+{
+  ACTIVE_COLLECTION_CHANGED,
+  LOAD_FINISHED,
+  LOAD_STARTED,
+  LAST_SIGNAL
+};
+
+static guint signals[LAST_SIGNAL] = { 0 };
+
 
 G_DEFINE_TYPE_WITH_PRIVATE (PhotosItemManager, photos_item_manager, PHOTOS_TYPE_BASE_MANAGER);
 
 
+static void
+photos_item_manager_add_object (PhotosBaseManager *mngr, GObject *object)
+{
+  PhotosItemManager *self = PHOTOS_ITEM_MANAGER (mngr);
+  PhotosItemManagerPrivate *priv = self->priv;
+  PhotosBaseItem *item;
+  const gchar *id;
+  gpointer *old_collection;
+
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (object));
+
+  item = PHOTOS_BASE_ITEM (object);
+
+  if (!photos_base_item_is_collection (item))
+    goto end;
+
+  id = photos_filterable_get_id (PHOTOS_FILTERABLE (item));
+  if (id == NULL)
+    goto end;
+
+  old_collection = g_hash_table_lookup (priv->collections, id);
+  if (old_collection != NULL)
+    goto end;
+
+  g_hash_table_insert (priv->collections, g_strdup (id), g_object_ref (item));
+
+ end:
+  PHOTOS_BASE_MANAGER_CLASS (photos_item_manager_parent_class)->add_object (mngr, object);
+}
+
+
 static void
 photos_item_manager_item_created_executed (TrackerSparqlCursor *cursor, gpointer user_data)
 {
@@ -89,7 +134,6 @@ static void
 photos_item_manager_changes_pending_foreach (gpointer key, gpointer value, gpointer user_data)
 {
   PhotosItemManager *self = PHOTOS_ITEM_MANAGER (user_data);
-  PhotosItemManagerPrivate *priv = self->priv;
   PhotosTrackerChangeEvent *change_event = (PhotosTrackerChangeEvent *) value;
   PhotosTrackerChangeEventType change_type;
   const gchar *change_urn;
@@ -117,8 +161,6 @@ photos_item_manager_changes_pending_foreach (gpointer key, gpointer value, gpoin
       if (object != NULL)
         {
           photos_base_item_destroy (PHOTOS_BASE_ITEM (object));
-          if (photos_base_item_is_collection (PHOTOS_BASE_ITEM (object)))
-            photos_base_manager_remove_object_by_id (priv->col_mngr, change_urn);
           photos_base_manager_remove_object_by_id (PHOTOS_BASE_MANAGER (self), change_urn);
         }
     }
@@ -132,6 +174,19 @@ photos_item_manager_changes_pending (PhotosItemManager *self, GHashTable *change
 }
 
 
+static void
+photos_item_manager_clear_active_item_load (PhotosItemManager *self)
+{
+  PhotosItemManagerPrivate *priv = self->priv;
+
+  if (priv->loader_cancellable != NULL)
+    {
+      g_cancellable_cancel (priv->loader_cancellable);
+      g_clear_object (&priv->loader_cancellable);
+    }
+}
+
+
 static void
 photos_item_manager_collection_path_free_foreach (gpointer data, gpointer user_data)
 {
@@ -139,64 +194,146 @@ photos_item_manager_collection_path_free_foreach (gpointer data, gpointer user_d
 }
 
 
+static gchar *
+photos_item_manager_get_where (PhotosBaseManager *mngr, gint flags)
+{
+  PhotosItemManager *self = PHOTOS_ITEM_MANAGER (mngr);
+  PhotosItemManagerPrivate *priv = self->priv;
+
+  if (priv->active_collection == NULL)
+    return g_strdup ("");
+
+  return photos_base_item_get_where (priv->active_collection);
+}
+
+
+static void
+photos_item_manager_item_load (GObject *source_object, GAsyncResult *res, gpointer user_data)
+{
+  PhotosItemManager *self = PHOTOS_ITEM_MANAGER (user_data);
+  PhotosItemManagerPrivate *priv = self->priv;
+  GError *error;
+  GeglNode *node = NULL;
+  PhotosBaseItem *item = PHOTOS_BASE_ITEM (source_object);
+
+  g_clear_object (&priv->loader_cancellable);
+
+  error = NULL;
+  node = photos_base_item_load_finish (item, res, &error);
+  if (error != NULL)
+    {
+      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+        g_warning ("Unable to load the item: %s", error->message);
+      g_error_free (error);
+    }
+
+  g_signal_emit (self, signals[LOAD_FINISHED], 0, item, node);
+
+  g_clear_object (&node);
+  g_object_unref (self);
+}
+
+
+static void
+photos_item_manager_remove_object_by_id (PhotosBaseManager *mngr, const gchar *id)
+{
+  PhotosItemManager *self = PHOTOS_ITEM_MANAGER (mngr);
+  PhotosItemManagerPrivate *priv = self->priv;
+  gpointer *collection;
+
+  if (id == NULL)
+    goto end;
+
+  collection = g_hash_table_lookup (priv->collections, id);
+  if (collection == NULL)
+    goto end;
+
+  g_hash_table_remove (priv->collections, id);
+
+ end:
+  PHOTOS_BASE_MANAGER_CLASS (photos_item_manager_parent_class)->remove_object_by_id (mngr, id);
+}
+
+
 static gboolean
 photos_item_manager_set_active_object (PhotosBaseManager *manager, GObject *object)
 {
   PhotosItemManager *self = PHOTOS_ITEM_MANAGER (manager);
   PhotosItemManagerPrivate *priv = self->priv;
-  GtkRecentManager *recent;
-  gboolean ret_val;
-  const gchar *uri;
+  GObject *active_item;
+  gboolean active_collection_changed = FALSE;
+  gboolean ret_val = FALSE;
+  gboolean start_loading = FALSE;
 
   g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (object) || object == NULL, FALSE);
 
-  ret_val = PHOTOS_BASE_MANAGER_CLASS (photos_item_manager_parent_class)->set_active_object (manager, object);
-
-  if (!ret_val)
-    goto out;
+  active_item = photos_base_manager_get_active_object (manager);
 
+  /* Passing NULL is a way to go back to the current collection or
+   * overview from the preview. However, you can't do that when you
+   * are looking at a collection.
+   */
   if (object == NULL)
-    goto out;
+    {
+      if (active_item != (GObject *) priv->active_collection)
+        object = (GObject *) priv->active_collection;
+      else
+        goto out;
+    }
+
+  photos_item_manager_clear_active_item_load (self);
+
+  /* This is when we are going back to the overview from the preview. */
+  if (object == NULL)
+    goto end;
 
   if (photos_base_item_is_collection (PHOTOS_BASE_ITEM (object)))
     {
-      GObject *collection;
+      /* This is when we are going back to the collection from the
+       * preview.
+       */
+      if (object == (GObject *) priv->active_collection)
+        goto end;
 
-      collection = photos_base_manager_get_active_object (priv->col_mngr);
-      g_queue_push_head (priv->collection_path, (collection != NULL) ? g_object_ref (collection) : NULL);
-      photos_base_manager_set_active_object (priv->col_mngr, object);
-      goto out;
+      g_queue_push_head (priv->collection_path,
+                         (priv->active_collection != NULL) ? g_object_ref (priv->active_collection) : NULL);
+
+      g_clear_object (&priv->active_collection);
+      priv->active_collection = g_object_ref (object);
+      active_collection_changed = TRUE;
     }
+  else
+    start_loading = TRUE;
 
-  recent = gtk_recent_manager_get_default ();
-  uri = photos_base_item_get_uri (PHOTOS_BASE_ITEM (object));
-  gtk_recent_manager_add_item (recent, uri);
+ end:
+  ret_val = PHOTOS_BASE_MANAGER_CLASS (photos_item_manager_parent_class)->set_active_object (manager, object);
+
+  if (ret_val && active_collection_changed)
+    g_signal_emit (self, signals[ACTIVE_COLLECTION_CHANGED], 0, priv->active_collection);
+
+  if (ret_val && start_loading)
+    {
+      GtkRecentManager *recent;
+      const gchar *uri;
+
+      recent = gtk_recent_manager_get_default ();
+      uri = photos_base_item_get_uri (PHOTOS_BASE_ITEM (object));
+      gtk_recent_manager_add_item (recent, uri);
+
+      priv->loader_cancellable = g_cancellable_new ();
+      photos_base_item_load_async (PHOTOS_BASE_ITEM (object),
+                                   priv->loader_cancellable,
+                                   photos_item_manager_item_load,
+                                   g_object_ref (self));
+
+      g_signal_emit (self, signals[LOAD_STARTED], 0, PHOTOS_BASE_ITEM (object), priv->loader_cancellable);
+    }
 
  out:
   return ret_val;
 }
 
 
-static GObject *
-photos_item_manager_constructor (GType                  type,
-                                 guint                  n_construct_params,
-                                 GObjectConstructParam *construct_params)
-{
-  static GObject *self = NULL;
-
-  if (self == NULL)
-    {
-      self = G_OBJECT_CLASS (photos_item_manager_parent_class)->constructor (type,
-                                                                             n_construct_params,
-                                                                             construct_params);
-      g_object_add_weak_pointer (self, (gpointer) &self);
-      return self;
-    }
-
-  return g_object_ref (self);
-}
-
-
 static void
 photos_item_manager_dispose (GObject *object)
 {
@@ -210,7 +347,9 @@ photos_item_manager_dispose (GObject *object)
       priv->collection_path = NULL;
     }
 
-  g_clear_object (&priv->col_mngr);
+  g_clear_pointer (&priv->collections, (GDestroyNotify) g_hash_table_unref);
+  g_clear_object (&priv->loader_cancellable);
+  g_clear_object (&priv->active_collection);
   g_clear_object (&priv->monitor);
 
   G_OBJECT_CLASS (photos_item_manager_parent_class)->dispose (object);
@@ -221,18 +360,13 @@ static void
 photos_item_manager_init (PhotosItemManager *self)
 {
   PhotosItemManagerPrivate *priv = self->priv;
-  GApplication *app;
-  PhotosSearchContextState *state;
 
   self->priv = photos_item_manager_get_instance_private (self);
   priv = self->priv;
 
-  app = g_application_get_default ();
-  state = photos_search_context_get_state (PHOTOS_SEARCH_CONTEXT (app));
-
+  priv->collections = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
   priv->extension_point = g_io_extension_point_lookup (PHOTOS_BASE_ITEM_EXTENSION_POINT_NAME);
   priv->collection_path = g_queue_new ();
-  priv->col_mngr = g_object_ref (state->col_mngr);
 
   priv->monitor = photos_tracker_change_monitor_dup_singleton (NULL, NULL);
   if (G_LIKELY (priv->monitor != NULL))
@@ -249,14 +383,54 @@ photos_item_manager_class_init (PhotosItemManagerClass *class)
   GObjectClass *object_class = G_OBJECT_CLASS (class);
   PhotosBaseManagerClass *base_manager_class = PHOTOS_BASE_MANAGER_CLASS (class);
 
-  object_class->constructor = photos_item_manager_constructor;
   object_class->dispose = photos_item_manager_dispose;
+  base_manager_class->add_object = photos_item_manager_add_object;
+  base_manager_class->get_where = photos_item_manager_get_where;
   base_manager_class->set_active_object = photos_item_manager_set_active_object;
+  base_manager_class->remove_object_by_id = photos_item_manager_remove_object_by_id;
+
+  signals[ACTIVE_COLLECTION_CHANGED] = g_signal_new ("active-collection-changed",
+                                                     G_TYPE_FROM_CLASS (class),
+                                                     G_SIGNAL_RUN_LAST,
+                                                     G_STRUCT_OFFSET (PhotosItemManagerClass,
+                                                                      active_collection_changed),
+                                                     NULL, /*accumulator */
+                                                     NULL, /*accu_data */
+                                                     g_cclosure_marshal_VOID__OBJECT,
+                                                     G_TYPE_NONE,
+                                                     1,
+                                                     PHOTOS_TYPE_BASE_ITEM);
+
+  signals[LOAD_FINISHED] = g_signal_new ("load-finished",
+                                         G_TYPE_FROM_CLASS (class),
+                                         G_SIGNAL_RUN_LAST,
+                                         G_STRUCT_OFFSET (PhotosItemManagerClass,
+                                                          load_finished),
+                                         NULL, /*accumulator */
+                                         NULL, /*accu_data */
+                                         g_cclosure_marshal_generic,
+                                         G_TYPE_NONE,
+                                         2,
+                                         PHOTOS_TYPE_BASE_ITEM,
+                                         GEGL_TYPE_NODE);
+
+  signals[LOAD_STARTED] = g_signal_new ("load-started",
+                                        G_TYPE_FROM_CLASS (class),
+                                        G_SIGNAL_RUN_LAST,
+                                        G_STRUCT_OFFSET (PhotosItemManagerClass,
+                                                         load_started),
+                                        NULL, /*accumulator */
+                                        NULL, /*accu_data */
+                                        g_cclosure_marshal_generic,
+                                        G_TYPE_NONE,
+                                        2,
+                                        PHOTOS_TYPE_BASE_ITEM,
+                                        G_TYPE_CANCELLABLE);
 }
 
 
 PhotosBaseManager *
-photos_item_manager_dup_singleton (void)
+photos_item_manager_new (void)
 {
   return g_object_new (PHOTOS_TYPE_ITEM_MANAGER, NULL);
 }
@@ -266,13 +440,23 @@ void
 photos_item_manager_activate_previous_collection (PhotosItemManager *self)
 {
   PhotosItemManagerPrivate *priv = self->priv;
-  GObject *collection;
+  gpointer *collection;
 
-  collection = G_OBJECT (g_queue_pop_head (priv->collection_path));
-  photos_base_manager_set_active_object (priv->col_mngr, collection);
+  photos_item_manager_clear_active_item_load (self);
 
-  if (collection == NULL)
-    photos_base_manager_set_active_object (PHOTOS_BASE_MANAGER (self), NULL);
+  collection = g_queue_pop_head (priv->collection_path);
+  g_assert (collection == NULL || PHOTOS_IS_BASE_ITEM (collection));
+
+  g_clear_object (&priv->active_collection);
+
+  if (collection != NULL)
+    g_object_ref (collection);
+  priv->active_collection = PHOTOS_BASE_ITEM (collection);
+
+  PHOTOS_BASE_MANAGER_CLASS (photos_item_manager_parent_class)
+    ->set_active_object (PHOTOS_BASE_MANAGER (self), (GObject *) collection);
+
+  g_signal_emit (self, signals[ACTIVE_COLLECTION_CHANGED], 0, priv->active_collection);
 
   g_clear_object (&collection);
 }
@@ -296,9 +480,6 @@ photos_item_manager_add_item (PhotosItemManager *self, TrackerSparqlCursor *curs
   item = photos_item_manager_create_item (self, cursor);
   photos_base_manager_add_object (PHOTOS_BASE_MANAGER (self), G_OBJECT (item));
 
-  if (photos_base_item_is_collection (item))
-    photos_base_manager_add_object (self->priv->col_mngr, G_OBJECT (item));
-
  out:
   g_clear_object (&item);
 }
@@ -351,3 +532,17 @@ photos_item_manager_create_item (PhotosItemManager *self, TrackerSparqlCursor *c
   g_free (identifier);
   return ret_val;
 }
+
+
+PhotosBaseItem *
+photos_item_manager_get_active_collection (PhotosItemManager *self)
+{
+  return self->priv->active_collection;
+}
+
+
+GHashTable *
+photos_item_manager_get_collections (PhotosItemManager *self)
+{
+  return self->priv->collections;
+}
