@@ -28,11 +28,12 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 
+#include "photos-base-manager.h"
 #include "photos-enums.h"
 #include "photos-icons.h"
-#include "photos-item-manager.h"
 #include "photos-preview-model.h"
 #include "photos-preview-nav-buttons.h"
+#include "photos-search-context.h"
 #include "photos-view-model.h"
 
 
@@ -262,7 +263,9 @@ photos_preview_nav_buttons_set_active_path (PhotosPreviewNavButtons *self)
   PhotosBaseItem *item;
   gchar *id;
 
-  gtk_tree_model_get_iter (priv->model, &iter, priv->current_path);
+  if (!gtk_tree_model_get_iter (priv->model, &iter, priv->current_path))
+    return;
+
   gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (priv->model), &child_iter, &iter);
   child_model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (priv->model));
   gtk_tree_model_get (child_model, &child_iter, PHOTOS_VIEW_MODEL_URN, &id, -1);
@@ -435,11 +438,16 @@ static void
 photos_preview_nav_buttons_init (PhotosPreviewNavButtons *self)
 {
   PhotosPreviewNavButtonsPrivate *priv;
+  GApplication *app;
+  PhotosSearchContextState *state;
 
   self->priv = photos_preview_nav_buttons_get_instance_private (self);
   priv = self->priv;
 
-  priv->item_mngr = photos_item_manager_dup_singleton ();
+  app = g_application_get_default ();
+  state = photos_search_context_get_state (PHOTOS_SEARCH_CONTEXT (app));
+
+  priv->item_mngr = g_object_ref (state->item_mngr);
 
   priv->action = PHOTOS_PREVIEW_ACTION_NONE;
 
